@@ -168,20 +168,26 @@ def metar_returner(metar_data, contents, months, years, number_of_flights,
     return contents
 
 
-def no_metar_returner(location, year, month, day, month_end, day_end,
+def no_metar_returner(location, dates, end_dates,
                       start_time_hours, end_time_hours, contents, number_of_flights,
                       replace_key="METAR_INFORMATION"):
     """Replaces the key word in a cell with note that no METAR information was
     available from the day"""
     metar_text = ""
     for flight in range(number_of_flights):
+        year = str(dates[flight])[:4]
+        year_end = str(end_dates[flight])[:4]
+        month = str(dates[flight])[4:6]
+        month_end = str(end_dates[flight])[4:6]
+        day = str(dates[flight])[6:8]
+        day_end = str(end_dates[flight])[6:8]
         # finds the locations that the metars were recorded from.
-        metar_text += "    \"No METARs for " + str(location[flight]) + " for the date " + str(day[flight]) + \
-                      str(month[flight]) + str(year[flight]) + " to the date " + str(day_end[flight]) + \
-                      str(month_end[flight]) + str(year[flight]) + \
+        metar_text += "    \"No METARs for " + str(location[flight]) + " for the date " + day + "/"+ \
+                      month + "/" + year + " to the date " + day_end + "/" + \
+                      month_end + "/" + year_end + \
                       " from a starting time of " + str(start_time_hours[flight]) + ":00 and an end time of " + \
                       str(int(end_time_hours[flight]) - 1) + ":59.\\n\",\n"
-    metar_text = metar_text[:-1]  # Removes "," from the end for json validity.
+    metar_text = metar_text[:-2]  # Removes "," from the end for json validity.
     # Creates replacement text for the METAR key.
     metar_replacement = "\n  {\n " + \
                         "  \"cell_type\": \"markdown\",\n" + \
