@@ -16,7 +16,7 @@ from autoflpy.util.testing.check_str_in_content import *
 
 
 def notebook_sample_code(flight_data_file_path, flight_data_file_name,
-                         arduino_data_file_path, arduino_flight_data_name):
+                         csv_data_file_path, csv_flight_data_name):
     """Sample flight log code for testing purposes"""
     # GRAPH_DATA_IMPORT
 
@@ -30,26 +30,26 @@ def notebook_sample_code(flight_data_file_path, flight_data_file_name,
     # flight_data_file_path = base_path
     # Excel File name
     # flight_data_file_name = "test_xlsx.xlsx"
-    # Arduino File name
-    # arduino_flight_data_name = "test_arduino.CSV"
-    # Arduino Data file path
-    # arduino_data_file_path = base_path
+    # CSV File name
+    # csv_flight_data_name = "test_csv.CSV"
+    # csv Data file path
+    # csv_data_file_path = base_path
     # Excel Sheets
     frame_list = flight_log_code.flight_data(flight_data_file_path,
                                              flight_data_file_name)
     # A list containing the date first and then the flight number
     date_and_flight_number = flight_log_code.date_and_flight_number(frame_list)
-    # Retrieves arduino flight data
-    arduino_micro_flight_data_frame = \
-        flight_log_code.arduino_micro_frame(arduino_data_file_path,
-                                            arduino_flight_data_name)
-    # Appends arduino frame to flight data from pixhawk
-    frame_list.append(arduino_micro_flight_data_frame)
+    # Retrieves csv flight data
+    csv_flight_data_frame = \
+        flight_log_code.csv_frame(csv_data_file_path,
+                                  csv_flight_data_name)
+    # Appends csv frame to flight data from pixhawk
+    frame_list.append(csv_flight_data_frame)
     # Sorts frames by time
     sorted_frames = flight_log_code.flight_data_time_sorter(frame_list)
     # Creates a list of all the values.
     values_list = flight_log_code.flight_data_and_axis(sorted_frames)
-    return (frame_list, date_and_flight_number, arduino_micro_flight_data_frame,
+    return (frame_list, date_and_flight_number, csv_flight_data_frame,
             sorted_frames, values_list)
 
 
@@ -69,18 +69,18 @@ class TestFlightLogCode(unittest.TestCase):
         # Defines variables
         flight_data_file_path = base_path
         flight_data_file_name = "test_xlsx.xlsx"
-        arduino_flight_data_file_path = base_path + data[
-            "flight_log_generator_input"]["arduino_flight_data_file_path"]
-        arduino_flight_data_name = data["flight_log_generator_input"
-        ]["arduino_flight_data_name"]
+        csv_flight_data_file_path = base_path + data[
+            "flight_log_generator_input"]["csv_flight_data_file_path"]
+        csv_flight_data_name = data["flight_log_generator_input"
+        ]["csv_flight_data_name"]
         # Creates a global variable to be used in the testing
         global notebook_results
         # Populates the global variable
         notebook_results = \
             notebook_sample_code(flight_data_file_path,
                                  flight_data_file_name,
-                                 arduino_flight_data_file_path,
-                                 arduino_flight_data_name)
+                                 csv_flight_data_file_path,
+                                 csv_flight_data_name)
 
     def setUp(self):
         # Sets up all of the test variables and locations to be used
@@ -101,12 +101,11 @@ class TestFlightLogCode(unittest.TestCase):
         self.flight_data_file_path = self.base_path  # Path to xlsx file
         self.flight_data_file_name = "test_xlsx.xlsx"
         self.flight_data_file_name_list = ["test_xlsx.xlsx"]
-        self.arduino_flight_data_file_path = self.base_path + self.data[
-            "flight_log_generator_input"]["arduino_flight_data_file_path"]
-        self.arduino_flight_data_name = self.data["flight_log_generator_input"
-        ]["arduino_flight_data_name"].replace(" ", "").split(",")
+        self.csv_flight_data_file_path = self.base_path + self.data[
+            "flight_log_generator_input"]["csv_flight_data_file_path"]
+        self.csv_flight_data_name = self.data["flight_log_generator_input"
+        ]["csv_flight_data_name"].replace(" ", "").split(",")
         self.flight_log_file_name_header = "test_generated_flight_log"
-        self.checklist_file_path = self.base_path
         self.start_time_hours = self.data["flight_log_generator_input"][
             "start_time_hours"].replace(" ", "").split(",")
         self.end_time_hours = self.data["flight_log_generator_input"][
@@ -146,18 +145,18 @@ class TestFlightLogCode(unittest.TestCase):
                                          self.flight_log_file_path,
                                          self.flight_data_file_path,
                                          self.flight_data_file_name_list,
-                                         self.arduino_flight_data_file_path,
-                                         self.arduino_flight_data_name,
+                                         self.csv_flight_data_file_path,
+                                         self.csv_flight_data_name,
                                          self.flight_date,
                                          self.flight_number,
                                          self.flight_log_file_name_header,
-                                         self.checklist_file_path,
                                          self.ICAO_airfield,
                                          self.start_time_hours,
                                          self.end_time_hours,
                                          self.metar_file_path,
                                          self.weather_data,
-                                         self.runway_data)
+                                         self.runway_data,
+                                         True)
         # This code tests the flight_log_maker function.
         # First, check that a file has been created.
         test_flight_log_file_path = self.base_path + 'test_generated_flight_logtest_xlsx.ipynb'
@@ -193,26 +192,6 @@ class TestFlightLogCode(unittest.TestCase):
             raise ValueError('Frame list length is not as expected: {0} != 11'
                              .format(len(frame_list)))
 
-    def test_checklist_finder(self):
-        # Loads a checklist
-        try:
-            frame_list = flight_log_code.flight_data(self.checklist_file_path,
-                                                     'Checklists_nominal.xlsx')
-            # Filters the checklist for the correct data
-            filtered_frame = \
-                flight_log_code.checklist_finder(frame_list,
-                                                 self.flight_number[0],
-                                                 self.flight_date[0])
-            # Check that the correct data was output
-            battery_voltage = filtered_frame['Battery Voltages'][2]
-            self.assertEqual('25.2', str(battery_voltage))
-            # Check that the ID also matches
-            id_chosen_frame = filtered_frame['ID'][2]
-            self.assertEqual('3', str(id_chosen_frame))
-        # Passes if the checklist is open.
-        except PermissionError:
-            self.assertEqual(1, 1)
-
     def test_flight_log_creator(self):
         # Generates content
         content = flight_log_code.contents_opener(self.template_file_path,
@@ -228,34 +207,6 @@ class TestFlightLogCode(unittest.TestCase):
                                        '_2.ipynb')
         self.assertTrue(file_exists)
 
-    def test_flight_log_checklist(self):
-        # Generates the content
-        content = flight_log_code.contents_opener(self.template_file_path,
-                                                  self.template_file_name)
-        # Creates checklist frames
-        frame_list_nominal = flight_log_code.flight_data(
-            self.checklist_file_path, "Checklists_nominal.xlsx")
-        frame_list_emergency = flight_log_code.flight_data(
-            self.checklist_file_path, "Checklists_emergency.xlsx")
-        # Filters checklist for the current flight
-        filtered_frame_nominal = flight_log_code.checklist_finder(
-            frame_list_nominal, self.flight_number[0], self.flight_date[0])
-        filtered_frame_emergency = flight_log_code.checklist_finder(
-            frame_list_emergency, self.flight_number[0], self.flight_date[0])
-        # Runs the flight_log_checklist code
-        content = \
-            flight_log_code.flight_log_checklist(filtered_frame_nominal,
-                                                 filtered_frame_emergency,
-                                                 "CHECKLIST_INFORMATION",
-                                                 content)[0]
-        # Checks that the content has been changed
-        expected_content = 'The Initial Pre-Flight was actioned by Adria' + \
-                           'n Weishaeupl starting at 2019-01-23 15:31:44 an' + \
-                           'd ending at 2019-01-23 15:32:58. The notes reco' + \
-                           'rded on this checklist were: <i>THIS IS A TEST.'
-        content_present = check_str_in_content(expected_content, content)
-        self.assertEqual(1, content_present)
-
     def test_date_and_flight_number(self):
         # Gets run in the Jupyter Notebook.
         # Extracts the desired variables from the sample notebook
@@ -265,20 +216,20 @@ class TestFlightLogCode(unittest.TestCase):
         self.assertEqual(expected_date_and_flight_number,
                          date_and_flight_number)
 
-    def test_arduino_micro_frame(self):
+    def test_csv_frame(self):
         # Gets run in the Jupyter Notebook.
         # Runs the sample notebook code to extract teh desired variable
-        arduino_micro_frame = notebook_results[2]
+        csv_frame = notebook_results[2]
         try:
             # Checks if the key is correct
-            arduino_micro_frame['X']
+            csv_frame['X']
             # Failed if no error is raised
             self.assertFalse(True)
         except KeyError:
             # Passes if an error is raised
             self.assertTrue(True)
         # Loads values
-        values = arduino_micro_frame['Temp0_degC_ArduinoMicro_20190123_Flight2'
+        values = csv_frame['Temp0_degC_ArduinoMicro_20190123_Flight2'
         ]
         # Compares expected values with values from the data frame
         expected_values = [24.38, 24.38, 24.38, 24.44, 25.31, 26.69, 27.69,
@@ -335,7 +286,7 @@ class TestFlightLogCode(unittest.TestCase):
     def test_file_type_finder(self):
         # Detects xlsx files from the test_files folder
         detected_files = flight_log_code.file_type_finder(self.base_path, ".xlsx")
-        expected_file_names = ['Checklists_emergency.xlsx', 'Checklists_nominal.xlsx', 'test_xlsx.xlsx']
+        expected_file_names = ['test_xlsx.xlsx']
         # Checks that all the expected files are present
         for file_name in expected_file_names:
             if file_name in detected_files:
@@ -347,7 +298,7 @@ class TestFlightLogCode(unittest.TestCase):
     def test_compile_and_compress(self):
         # Runs the compiler and compressor.
         flight_log_code.compile_and_compress(self.flight_data_file_path, [self.flight_data_file_name],
-                                             self.arduino_flight_data_file_path, self.arduino_flight_data_name,
+                                             self.csv_flight_data_file_path, self.csv_flight_data_name,
                                              self.comp_data_file_path)
         pickle_file_name = self.base_path + "test_xlsx.pkl"  # Defines the file name
         # Checks that the file exists
@@ -355,12 +306,16 @@ class TestFlightLogCode(unittest.TestCase):
 
     def test_dictionary_reader(self):
         # Returns a string of formatted weather data
-        read_data = flight_log_code.dictionary_reader(self.weather_data_dict, units_present=True)
+        read_data = flight_log_code.dictionary_reader(self.weather_data_dict, units_present=True, flight_number="1")
         # Adds a string of formatted runway data
-        read_data += flight_log_code.dictionary_reader(self.runway_data_dict, units_present=False)
-        expected_results = ["Action time : 12:34 hh:mm", "Pressure : 1234567 Pa", "Temperature : -12.3 C",
-                            "Wind direction : 123 degrees", "Wind speed : 12.3 mps", "take off direction : 321",
-                            "runway surface : XYZ", "surface condition : ZYX"]
+        read_data += flight_log_code.dictionary_reader(self.runway_data_dict, units_present=False, flight_number="2")
+        expected_results = [" | Flight | Action time  (hh:mm) | Pressure  (Pa) | Temperature  (C) | Wind direction"
+                            "  (degrees) | Wind speed  (mps) |",
+                            " | --- | --- | --- | --- | --- | --- |",
+                            "| Flight 1| 12:34 | 1234567 | -12.3 | 123 | 12.3 |",
+                            " | Flight | runway surface  | surface condition  | take off direction  |",
+                            " | --- | --- | --- | --- |",
+                            "| Flight 2| XYZ | ZYX | 321 |"]
         # Checks that the correct data is present in the read_data string
         for string in expected_results:
             self.assertTrue(string in read_data)
